import * as api from './api/base.js'

App({
  store: {
    token: '',
    pageshow: false,
    user: {} // 用户信息
  },
  onLaunch: function () {
    // 加载自定义字体
    wx.loadFontFace({
      global: true,
      family: 'my',
      source: 'https://webapp-pub.ezijing.com/weapp/share/my.ttf',
      scopes: ['webview', 'native']
    })
    this.store.token = wx.getStorageSync('token')
  },
  onPageNotFound() {
    wx.redirectTo({ url: 'pages/login/index' })
  },
  checkPageshow(callback) {
    if (this.store.pageshow) {
      callback && callback(true)
      return true
    }
    wx.showNavigationBarLoading()
    api.getPageShowStatus().then(response => {
      const show = response.code === 1
      this.store.pageshow = show
      callback && callback(show, response)
      wx.hideNavigationBarLoading()
    })
  },
  // 获取用户信息
  getUser(params) {
    return api.getUser(params).then(response => {
      this.store.user = response
      wx.setStorage({ key: 'uid', data: response.id })
      wx.setStorage({ key: 'sid', data: response.student_info.id })
      return response
    })
  },
  // 退出登录
  logout() {
    return api.logout().then(response => {
      this.setToken('')
      wx.removeStorageSync('token')
    })
  },
  setToken(token) {
    this.store.token = token
    try {
      wx.setStorageSync('token', token)
    } catch (e) {
      wx.showToast({ title: 'Token 存储失败', icon: 'error' })
      console.log(e)
    }
  },
  // 检查权限
  async checkAccess(token) {
    if (token) this.setToken(token)
    if (!this.store.token) return false
    try {
      const user = await this.getUser({ check: true })
      return !!user?.id
    } catch (error) {
      console.log(error)
      return false
    }
  }
})
